summaryrefslogtreecommitdiffstats
path: root/include
diff options
context:
space:
mode:
Diffstat (limited to 'include')
-rw-r--r--include/httpd.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/include/httpd.h b/include/httpd.h
index 256b3fc1c3..f71373e0c0 100644
--- a/include/httpd.h
+++ b/include/httpd.h
@@ -1450,18 +1450,18 @@ AP_DECLARE(int) ap_is_matchexp(const char *str);
/**
* Determine if a string matches a patterm containing the wildcards '?' or '*'
* @param str The string to check
* @param exp The pattern to match against
* @return 1 if the two strings match, 0 otherwise
*/
-AP_DECLARE(int) ap_strcmp_match(const char *str, const char *exp);
+AP_DECLARE(int) ap_strcmp_match(const char *str, const char *expected);
/**
* Determine if a string matches a patterm containing the wildcards '?' or '*',
* ignoring case
* @param str The string to check
* @param exp The pattern to match against
* @return 1 if the two strings match, 0 otherwise
*/
-AP_DECLARE(int) ap_strcasecmp_match(const char *str, const char *exp);
+AP_DECLARE(int) ap_strcasecmp_match(const char *str, const char *expected);
/**
* Find the first occurrence of the substring s2 in s1, regardless of case
@@ -1450,18 +1450,18 @@ AP_DECLARE(int) ap_is_matchexp(const char *str);
* Determine if a string matches a patterm containing the wildcards '?' or '*'
* @param str The string to check
- * @param exp The pattern to match against
+ * @param expected The pattern to match against
* @return 1 if the two strings match, 0 otherwise
*/
@@ -1450,18 +1450,18 @@ AP_DECLARE(int) ap_is_matchexp(const char *str);
* ignoring case
* @param str The string to check
- * @param exp The pattern to match against
+ * @param expected The pattern to match against
* @return 1 if the two strings match, 0 otherwise
*/